Skip to main contentModule arithmetic
Source - masked_add
- Add two masked arrays elementwise with
NumPy broadcasting. - masked_add_array
- Add a masked array and a regular array, treating the regular array as
unmasked. Broadcasts within the same dimension type.
- masked_div
- Divide two masked arrays elementwise with
NumPy broadcasting. - masked_div_array
- Divide a masked array by a regular array, treating the regular array as
unmasked. Broadcasts within the same dimension type.
- masked_mul
- Multiply two masked arrays elementwise with
NumPy broadcasting. - masked_mul_array
- Multiply a masked array and a regular array, treating the regular array
as unmasked. Broadcasts within the same dimension type.
- masked_sub
- Subtract two masked arrays elementwise with
NumPy broadcasting. - masked_sub_array
- Subtract a regular array from a masked array, treating the regular array
as unmasked. Broadcasts within the same dimension type.